[GRASS-SVN] r38642 - grass/trunk/lib/vector/rtree
svn_grass at osgeo.org
svn_grass at osgeo.org
Sat Aug 8 06:13:18 EDT 2009
Author: mmetz
Date: 2009-08-08 06:13:17 -0400 (Sat, 08 Aug 2009)
New Revision: 38642
Modified:
grass/trunk/lib/vector/rtree/index.h
grass/trunk/lib/vector/rtree/split.c
Log:
RTree performance compromise
Modified: grass/trunk/lib/vector/rtree/index.h
===================================================================
--- grass/trunk/lib/vector/rtree/index.h 2009-08-08 10:12:27 UTC (rev 38641)
+++ grass/trunk/lib/vector/rtree/index.h 2009-08-08 10:13:17 UTC (rev 38642)
@@ -45,10 +45,10 @@
* this is LFS dependent, not good
* on 32 bit without LFS this is 9.69
* on 32 bit with LFS and on 64 bit this is 9 */
-#define MAXCARD 10
+#define MAXCARD 9
/* R*-tree: number of branches to be force-reinserted when adding a branch */
-#define FORCECARD 3
+#define FORCECARD 2
/* maximum no of levels = tree depth */
#define MAXLEVEL 20 /* 4^MAXLEVEL items are guaranteed to fit into the tree */
Modified: grass/trunk/lib/vector/rtree/split.c
===================================================================
--- grass/trunk/lib/vector/rtree/split.c 2009-08-08 10:12:27 UTC (rev 38641)
+++ grass/trunk/lib/vector/rtree/split.c 2009-08-08 10:13:17 UTC (rev 38642)
@@ -85,7 +85,7 @@
/**********************************************************************
* *
* Toni Guttmann's quadratic splitting method *
* *
**********************************************************************/
@@ -207,7 +207,7 @@
}
/*----------------------------------------------------------------------
-| Method #0 for choosing a partition: this is Toni Guttmann's quadratic
+| Method #0 for choosing a partition: this is Toni Guttman's quadratic
| split
|
| As the seeds for the two groups, pick the two rects that would waste
@@ -85,7 +85,7 @@
/**********************************************************************
* *
- * Toni Guttmann's quadratic splitting method *
+ * Toni Guttman's quadratic splitting method *
* *
**********************************************************************/
More information about the grass-commit
mailing list